Crate rubbler

source ·
Rubbler

Rubbler is a RISC-V assembler written in Rust 🦀. This library was written with the main purpose of embedding a simple RISC-V assembler inside of a RISC-V CPU test bench code written with verilator.

Modules

  • Exports C interfaces for functions provided by the crate module to enable binding with foreign code.

Functions

  • Assemble the given source string and returns a vector of bytes of the assembled source string if the source string is a valid (and supported) RISC-V assembly source code.
  • Assemble the file specified in path and returns a vector of bytes of the assembled source file if the source file is a valid (and supported) RISC-V assembly source code.
  • Assemble the given instruction string and returns a u32 value of the assembled instruction string.